"""
Application-class that implements pyFoamClearCase.py
"""

from PyFoamApplication import PyFoamApplication

from PyFoam.RunDictionary.SolutionDirectory import SolutionDirectory

class ClearCase(PyFoamApplication):
    def __init__(self,args=None):
        description="""
Removes all timesteps but the first from a case-directory.
Also removes other data that is generated by sovers/utilities/PyFoam
"""
        PyFoamApplication.__init__(self,args=args,description=description,usage="%prog <caseDirectory>",interspersed=True,nr=1)

    def addOptions(self):
        self.parser.add_option("--after",
                         type="float",
                         dest="after",
                         default=None,
                         help="Only remove timesteps after this time")
        self.parser.add_option("--processor",
                         action="store_true",
                         dest="processor",
                         default=False,
                         help="Keep the processor directories")
        self.parser.add_option("--no-pyfoam",
                         action="store_false",
                         dest="pyfoam",
                         default=True,
                         help="Keep the PyFoam-specific directories and logfiles")
        self.parser.add_option("--keep-last",
                         action="store_true",
                         dest="latest",
                         default=False,
                         help="Keep the data from the last time-step")

    def run(self):
        cName=self.parser.getArgs()[0]
        
        sol=SolutionDirectory(cName,archive=None,paraviewLink=False)
        sol.clear(after=self.parser.getOptions().after,
                  processor=self.parser.getOptions().processor,
                  pyfoam=self.parser.getOptions().pyfoam,
                  keepLast=self.parser.getOptions().latest)
        
